========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs|
    * - tests
      - | |travis|
        | |appveyor|
        | |codecov|
    * - package
      - | |version|
        | |wheel|
        | |supported-versions|
        | |supported-implementations|
        | |commits-since|
    * - citable
      - |zenodo|
    * - Example notebooks
      - |example-notebooks|

.. |docs| image:: https://readthedocs.org/projects/python-dts-calibration/badge/?style=flat
    :target: https://python-dts-calibration.readthedocs.io/en/latest/
    :alt: Documentation Status

.. |travis| image:: https://travis-ci.org/dtscalibration/python-dts-calibration.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/dtscalibration/python-dts-calibration

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/we2caropyby30nd1?svg=true
    :alt: AppVeyor Build Status
    :target: https://ci.appveyor.com/project/bdestombe/python-dts-calibration

.. |codecov| image:: https://codecov.io/github/dtscalibration/python-dts-calibration/coverage.svg?branch=master
    :alt: Coverage Status
    :target: https://codecov.io/github/dtscalibration/python-dts-calibration

.. |version| image:: https://img.shields.io/pypi/v/dtscalibration.svg
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/dtscalibration

.. |commits-since| image:: https://img.shields.io/github/commits-since/dtscalibration/python-dts-calibration/v0.7.0.svg
    :alt: Commits since latest release
    :target: https://github.com/dtscalibration/python-dts-calibration/compare/v0.7.0...master

.. |wheel| image:: https://img.shields.io/pypi/wheel/dtscalibration.svg
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/dtscalibration

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/dtscalibration.svg
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/dtscalibration

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/dtscalibration.svg
    :alt: Supported implementations
    :target: https://pypi.python.org/pypi/dtscalibration

.. |zenodo| image:: https://zenodo.org/badge/143077491.svg
   :alt: It would be greatly appreciated if you could cite this package in eg articles presentations
   :target: https://zenodo.org/badge/latestdoi/143077491

.. |example-notebooks| image:: https://mybinder.org/badge.svg
   :alt: Interactively run the example notebooks online
   :target: https://mybinder.org/v2/gh/dtscalibration/python-dts-calibration/master?filepath=examples%2Fnotebooks

.. end-badges

A Python package to load raw DTS files, perform a calibration, and plot the result

* Free software: BSD 3-Clause License

Installation
============

::

    pip install dtscalibration
    
Or the development version directly from GitHub

::

    pip install https://github.com/dtscalibration/python-dts-calibration/zipball/master --upgrade

Learn by examples
=================
Interactively run the example notebooks online by clicking the launch-binder button.

Documentation
=============

https://python-dts-calibration.readthedocs.io/

